@@ -40,7 +40,7 @@ db_path: str = "FA.db"
 
 
 def clean_username(username: str, exclude: str = "") -> str:
-    return str(re_sub(rf"[^a-zA-Z0-9\-.~,{exclude}]", "", username.lower().strip()))
+    return str(re_sub(rf"[^a-zA-Z0-9\-.~{exclude}]", "", username.lower().strip()))
 
 
 def button(href: str, text: str) -> str:
@@ -241,6 +241,15 @@ def search_user_journals(username: str):
         "search", table="journals", **{**{k: request.args.getlist(k) for k in request.args}, "author": username}))
 
 
+@app.route("/favorites/<username>")
+@app.route("/search/favorites/<username>/")
+def search_user_favorites(username: str):
+    return redirect(url_for(
+        "search", table="submissions", **{
+            **{k: request.args.getlist(k) for k in request.args},
+            "favorite": f"%{username}%"}))
+
+
 @app.route("/search/<string:table>/")
 def search(table: str):
     table = table.lower()
@@ -260,11 +269,13 @@ def search(table: str):
     columns_results: List[str]
     columns_list: List[str]
     column_id: str
-    limit: int = int(request.args.get("limit", 50))
+    limit: int = int(request.args.get("limit", 48))
     page: int = int(request.args.get("page", 1))
     sort: str = request.args.get("sort", "").lower()
     order: str = request.args.get("order", "").lower()
-    view: str = v if (v := request.args.get("view", "list").lower()) in ("list", "grid") else "list"
+    view: str = request.args.get("view", "").lower()
+    view = "grid" if view not in ("list", "grid") and table == "submissions" else view
+    view = "list" if table != "submissions" else view
 
     results, columns_table, columns_results, columns_list, column_id, sort, order = search_table(
         table,
@@ -378,9 +389,11 @@ def submission_file(id_: int, filename: str = ""):
 @lru_cache
 @app.route("/submission/<int:id_>/thumbnail/")
 @app.route("/submission/<int:id_>/thumbnail/<string:filename>")
-@app.route("/submission/<int:id_>/thumbnail/<int:size>/")
-@app.route("/submission/<int:id_>/thumbnail/<int:size>/<string:filename>")
-def submission_thumbnail(id_: int, size: int = 150, filename: str = None):
+@app.route("/submission/<int:id_>/thumbnail/<int:x>/")
+@app.route("/submission/<int:id_>/thumbnail/<int:x>/<string:filename>")
+@app.route("/submission/<int:id_>/thumbnail/<int:x>x<int:y>/")
+@app.route("/submission/<int:id_>/thumbnail/<int:x>x<int:y>/<string:filename>")
+def submission_thumbnail(id_: int, x: int = 150, y: int = 150, filename: str = None):
     sub_ext, sub_dir = load_submission_file(id_)
 
     if sub_ext is None:
@@ -392,7 +405,7 @@ def submission_thumbnail(id_: int, size: int = 150, filename: str = None):
         sub_ext = "jpeg" if sub_ext == "jpg" else sub_ext
         f_obj: BytesIO = BytesIO()
         with Image.open(path) as img:
-            img.thumbnail((size, size))
+            img.thumbnail((x, y))
             img.save(f_obj, sub_ext)
         f_obj.seek(0)
         return send_file(f_obj, attachment_filename=filename, mimetype=f"image/{sub_ext}")
